/***********************************************************************************************
* this is a short description for making an own Plugin for the fuzzyIDE                        *
*                                                                                              *
* use this sceleton to start writing your own plugin                                           *
* see <plugin_howtodo.pdf> or <http://www.htw-dresden.de/~easybot/ > for further information   *
*                                                                                              *
************************************************************************************************/
package myplugin;


// all Classes provided with the fuzzyIDE-framework (fuzzyide.jar)
import de.htwdd.robotic.fuzzyide.AbstractPlugin;
import de.htwdd.robotic.fuzzyide.plugman.Plugable;
import de.htwdd.robotic.fuzzyide.plugman.DataModelAccessable;
import de.htwdd.robotic.fuzzyide.plugman.Viewable;
import de.htwdd.robotic.fuzzyide.xmlmodel.ModelObserver;
import de.htwdd.robotic.fuzzyide.xmlmodel.FuzzyModel;
import de.htwdd.robotic.fuzzyide.gui.*;   //important to use Viewcomponents in your Plugin

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.util.Observable;


/**
 *  This class is the main class for the MyPlugin.
 *
 * @author  Daniel Kubis
 * @version  07.11.2002
 *
 */

public class MyPlugin extends AbstractPlugin
            // you can extend AbstractPlugin or implement Plugable to register youself as an Plugin
            implements
            ModelObserver,          // used to get informed about changes on the DataModel
            DataModelAccessable,    // used to get access to the DataModel (XML-Model)
           /* Viewable, // already implemented in AbstractPlugin*/    // used to get access to the desktop (using, changing Internalframes)
            ActionListener          // handling Pluginintern ActionEvents
{

    // the JMenu
    private JMenu menu;
    private JMenuItem miMyPlugin;
    private InternalFrame iframe;

    // my Mainpanel
    private JPanel pMyPluginView;
    // my ConfigPanel
    private JPanel pMyPluginConfig;

    /**
     *  Constructor
     */
    public MyPlugin()
    {
        //this constructor is called when the plugin is loaded while the programm is starting
    }

    /*********************************************************************************************/
    // inherited from AbstractPlugin (or Plugable)
    /**
     *  called in the init-Method of AbstractPlugin
     */
    public void initComponents()
    {
        //here you can init your Plugincomponents
        this.pMyPluginView = new JPanel();
        this.pMyPluginView.add(new JLabel("This is an exampleplugin"));
        this.pMyPluginConfig = new JPanel();
    }


    // inherited from Plugable
    /**
     *  called if the whole Program is exited
     */
    public void exit()
    {
        //do all the final stuff
    }

    /**
     *  Gets the configPanel attribute of the Plugin
     *
     *@return    The configPanel value
     */
    public JPanel getConfigPanel()
    {
        //Panel to make any configuration on the Plugin
        return this.pMyPluginConfig; //return null if you don't need a config-panel
    }


    /**
     *  Gets the JMenu attribute of the Plugin
     *
     *@return    The JMenuItem value
     */
    public JMenuItem getJMenuItem()
    {
        //this menu or menuitem will be added to the "Plugins"-menu in the Program
        this.menu = new JMenu("MyPlugin");
        this.miMyPlugin = new JMenuItem("show");
        this.miMyPlugin.addActionListener(this);
        this.menu.add(this.miMyPlugin);
        return this.menu;
    }


    /**
     *  Gets the name attribute of the Plugin
     *
     *@return    The name value
     */
    public String getName()
    {
        //used to register the Plugin at the Mainprogram
        return new String("myPlugin");
    }
    //end Plugable and AbstractPlugin

    /*********************************************************************************************/

    // inherited from ModelObserver
    /**
     *  automatically called, when the model has changed
     *
     *@param  obs  the Obserable object - the FuzzyModel
     *@param  obj  an Object given by the FuzzyModel - can be ignored
     */
    public void update(Observable obs, Object obj)
    {
        // make all the things to be done if sth. at the model has changed

        // paint my Mainpanel --> this is not a must!
        this.pMyPluginView.invalidate();
        this.pMyPluginView.validate();
        this.pMyPluginView.repaint();
    }
    // end ModelObserver

    /*********************************************************************************************/

    // inherited from DataModelAccessable
    /**
     *  called when a datamodel is created gives the plugin the reference to the
     *  datamodel inside this method the plugin should register his observation
     *
     *@param  fm  the FuzzyModel
     */
    public void dataModelCreated(FuzzyModel fm)
    {
        // now you can use the DataModel and manipulate it --> see FuzzyModel.java API
    }

    /**
     *  called when a datamodel is closed after this method there is no dataModel
     *  available
     */
    public void dataModelClosed()
    {
        //close all Windows and do all the things to be done when there will be an other model
    }
    //end DataModelAccessable

    /*********************************************************************************************/

    //inherited from Viewable
    /**
     *  called when a the view is created
     *  gives the plugin the reference to the view
     *  inside this method the plugin should register his observation
     */
/*    public void viewCreated(ViewInterface v)
    {
        already implemented in AbstractPlugin
    }
*/
    //end Viewable
    /*********************************************************************************************/


    // inherited from ActionListener
    /**
     *  Description of the Method
     *
     *@param  e  Description of the Parameter
     */
    public void actionPerformed(ActionEvent e)
    {
        // add a JInternalFrame to the Desktop if the Menuitem is clicked
        if (e.getSource() == this.miMyPlugin)
        {
            //view is inherited from AbstractPlugin
            if (!this.view.isIFOnDesktop(iframe))
            {
                iframe = this.view.getInternalFrame(this);
                iframe.setTitle("my first Window");
                iframe.getContentPane().add(this.pMyPluginView);
                iframe.pack();
            }
            iframe.setSize(250,250);
            iframe.show();
        }

        /* handle other actions now....
        if (e.getSource() == ???)
        {

    }
        ... */
    }
}

/*********************************************************************************************/
//END ... now you have done all you had to do
//see <plugin_howtodo.pdf> for further information
/*********************************************************************************************/
